@@ -1,6 +1,8 @@
 import numpy as np
 import pandas as pd
 import matplotlib.pyplot as plt
+from jcopml.plot import plot_confusion_matrix, plot_actual_vs_prediction, plot_residual
+
 from jcopml.feature_importance import mean_score_decrease
 
 from jcopml.utils import save_model
@@ -123,7 +125,13 @@ class AutoRegressor(AutoBase):
             list of numerical column names in the dataframe
 
         cat_feature: list of str
-            list of categorical column names in the dataframe
+            list of categorical column names in the dataframe (Would be OneHot encoded)
+
+        processed_num_feature; list of str
+            list of numerical column to be used as is (except for imputation)
+
+        processed_cat_feature; list of str
+            list of ordinal categorical column to be used as is (except for imputation)
 
         random_state: int or None
             random state for parameter search
@@ -198,6 +206,18 @@ class AutoRegressor(AutoBase):
         self.cv_results = self._cv_results()
         self.report()
 
+    def plot_actual_vs_prediction(self):
+        plot_actual_vs_prediction(self.X_train, self.y_train, self.X_test, self.y_test, self.model)
+
+    def plot_residual(self, lowess=False):
+        """
+        Residual plot
+
+        lowess: bool
+            include the LOWESS (Locally Weighted Scatterplot Smoothing) line
+        """
+        plot_residual(self.X_train, self.y_train, self.X_test, self.y_test, self.model, lowess=lowess)
+
 
 class AutoClassifier(AutoBase):
     def __init__(self, num_feature, cat_feature, processed_num_feature=[], processed_cat_feature=[], random_state=42):
@@ -215,7 +235,13 @@ class AutoClassifier(AutoBase):
             list of numerical column names in the dataframe
 
         cat_feature: list of str
-            list of categorical column names in the dataframe
+            list of categorical column names in the dataframe (Would be OneHot encoded)
+
+        processed_num_feature; list of str
+            list of numerical column to be used as is (except for imputation)
+
+        processed_cat_feature; list of str
+            list of ordinal categorical column to be used as is (except for imputation)
 
         random_state: int or None
             random state for parameter search
@@ -290,6 +316,9 @@ class AutoClassifier(AutoBase):
         self.cv_results = self._cv_results()
         self.report()
 
+    def plot_confusion_matrix(self):
+        plot_confusion_matrix(self.X_train, self.y_train, self.X_test, self.y_test, self.model)
+
 
 def _parse_prep_numeric(pipe):
     params = pipe.get_params()
