@@ -1,3 +1,4 @@
+import pandas as pd
 import os
 from warnings import warn
 
@@ -84,7 +85,7 @@ def num_pipe(impute='median', poly=None, transform=None, scaling=None, memory=No
         return Pipeline(steps)
 
 
-def cat_pipe(impute='most_frequent', encoder=None, memory=False):
+def cat_pipe(impute='most_frequent', encoder='onehot', memory=False):
     """
     A scikit-learn categorical pipeline used in ColumnTransformer
 
