@@ -31,13 +31,13 @@ def plot_residual(X_train, y_train, X_test, y_test, model, lowess=False):
     plt.figure(figsize=(15, 5))
 
     plt.subplot(121)
-    sns.residplot(model.predict(X_train), y_train, lowess=lowess, scatter_kws={'s': 10, 'color': 'b'})
+    sns.residplot(x=model.predict(X_train), y=y_train, lowess=lowess, scatter_kws={'s': 10, 'color': 'b'})
     plt.xlabel("Prediction", fontsize=14)
     plt.ylabel("Residual", fontsize=14)
     plt.title("Train")
 
     plt.subplot(122)
-    sns.residplot(model.predict(X_test), y_test, lowess=lowess, scatter_kws={'s': 10, 'color': 'b'})
+    sns.residplot(x=model.predict(X_test), y=y_test, lowess=lowess, scatter_kws={'s': 10, 'color': 'b'})
     plt.xlabel("Prediction", fontsize=14)
     plt.ylabel("Residual", fontsize=14)
     plt.title("Test");
