@@ -1,6 +1,9 @@
-from statsmodels.tsa.stattools import adfuller, kpss
-import pandas as pd
 import warnings
+import pandas as pd
+import matplotlib.pyplot as plt
+
+from statsmodels.tsa.stattools import adfuller, kpss
+from statsmodels.graphics.tsaplots import plot_acf, plot_pacf
 
 
 def stationarity_tester(time_series, dropna=True):
@@ -53,3 +56,18 @@ def _kpss_test(time_series):
             df[f'Critical Value ({k})'] = v
     df["reject_null"] = (p_value <= 0.05)
     return df
+
+
+def plot_acf_pacf(series, figsize=(15, 8), dropna=True):
+    if dropna:
+        series = series.dropna()
+
+    plt.figure(figsize=figsize)
+    plt.subplot(211)
+    plt.plot(series, "b-")
+
+    ax1 = plt.subplot(223)
+    plot_acf(series, lags=50, ax=ax1, title="ACF", color="b", alpha=None);
+
+    ax2 = plt.subplot(224)
+    plot_pacf(series, lags=50, ax=ax2, title="PACF", color="r", alpha=None);
